==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebTransactionServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTransactionServiceDescription } from "./WebTransactionServiceDescription";
/**
 * @hidden
 */
var WebTransactionServiceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTransactionServiceDescriptionMetadata, _super);
    function WebTransactionServiceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTransactionServiceDescriptionMetadata.b = function (a) {
        if (WebTransactionServiceDescriptionMetadata.a == null) {
            WebTransactionServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTransactionServiceDescriptionMetadata.c(WebTransactionServiceDescriptionMetadata.a);
        }
        if (a.j(WebTransactionServiceDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTransactionServiceDescriptionMetadata.a);
    };
    WebTransactionServiceDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TransactionService");
    };
    WebTransactionServiceDescriptionMetadata.d = function (a) {
        WebTransactionServiceDescriptionMetadata.b(a);
        a.aa("WebTransactionService", function () { return new WebTransactionServiceDescription(); });
        a.z("WebTransactionService", WebTransactionServiceDescriptionMetadata.a);
    };
    WebTransactionServiceDescriptionMetadata.$t = markType(WebTransactionServiceDescriptionMetadata, 'WebTransactionServiceDescriptionMetadata');
    WebTransactionServiceDescriptionMetadata.a = null;
    return WebTransactionServiceDescriptionMetadata;
}(Base));
export { WebTransactionServiceDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebTransactionServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTransactionServiceDescription } from "./WebTransactionServiceDescription";
/**
 * @hidden
 */
var WebTransactionServiceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTransactionServiceDescriptionMetadata, _super);
    function WebTransactionServiceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTransactionServiceDescriptionMetadata.b = function (a) {
        if (WebTransactionServiceDescriptionMetadata.a == null) {
            WebTransactionServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTransactionServiceDescriptionMetadata.c(WebTransactionServiceDescriptionMetadata.a);
        }
        if (a.k(WebTransactionServiceDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebTransactionServiceDescriptionMetadata.a);
    };
    WebTransactionServiceDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TransactionService");
    };
    WebTransactionServiceDescriptionMetadata.d = function (a) {
        WebTransactionServiceDescriptionMetadata.b(a);
        a.ac("WebTransactionService", function () { return new WebTransactionServiceDescription(); });
        a.ab("WebTransactionService", WebTransactionServiceDescriptionMetadata.a);
    };
    WebTransactionServiceDescriptionMetadata.$t = markType(WebTransactionServiceDescriptionMetadata, 'WebTransactionServiceDescriptionMetadata');
    WebTransactionServiceDescriptionMetadata.a = null;
    return WebTransactionServiceDescriptionMetadata;
}(Base));
export { WebTransactionServiceDescriptionMetadata };
